diff --git a/htdocs/core/lib/functions.lib.php b/htdocs/core/lib/functions.lib.php
index c761ac3cc86..589ec69b12a 100644
--- a/htdocs/core/lib/functions.lib.php
+++ b/htdocs/core/lib/functions.lib.php
@@ -8101,6 +8101,11 @@ function dolGetStatus($statusLabel = '', $statusLabelShort = '', $html = '', $st
$return = '';
+ $dolGetBadgeParams = array();
+ if(!empty($params['badgeParams'])){
+ $dolGetBadgeParams = $params['badgeParams'];
+ }
+
// image's filename are still in French
$statusImg=array(
'status0' => 'statut0'
@@ -8156,13 +8161,13 @@ function dolGetStatus($statusLabel = '', $statusLabelShort = '', $html = '', $st
$statusLabelShort = !empty($statusLabelShort)?$statusLabelShort:$statusLabel;
if ($displayMode == 3) {
- $return = dolGetBadge($statusLabel, '', $statusType, 'dot');
+ $return = dolGetBadge($statusLabel, '', $statusType, 'dot', $url, $dolGetBadgeParams);
}
elseif ($displayMode === 5) {
- $return = dolGetBadge($statusLabelShort, $html, $statusType);
+ $return = dolGetBadge($statusLabelShort, $html, $statusType, '', $url, $dolGetBadgeParams);
}
else {
- $return = dolGetBadge($statusLabel, $html, $statusType);
+ $return = dolGetBadge($statusLabel, $html, $statusType, '', $url, $dolGetBadgeParams);
}
}
diff --git a/htdocs/fourn/class/fournisseur.commande.class.php b/htdocs/fourn/class/fournisseur.commande.class.php
index 3428a49aba5..4536cdc5bbd 100644
--- a/htdocs/fourn/class/fournisseur.commande.class.php
+++ b/htdocs/fourn/class/fournisseur.commande.class.php
@@ -625,18 +625,17 @@ class CommandeFournisseur extends CommonOrder
/**
* Return label of a status
*
* @param int $statut Id statut
* @param int $mode 0=Long label, 1=Short label, 2=Picto + Short label, 3=Picto, 4=Picto + Long label, 5=Short label + Picto
* @param int $billed 1=Billed
* @return string Label of status
*/
- public function LibStatut($statut, $mode = 0, $billed = 0)
+ public function LibStatut($status, $mode = 0, $billed = 0)
{
// phpcs:enable
global $conf, $langs;
- if (empty($this->statuts) || empty($this->statutshort))
- {
+ if (empty($this->statuts) || empty($this->statutshort)){
$langs->load('orders');
$this->statuts[0] = 'StatusSupplierOrderDraft';
@@ -662,55 +661,33 @@ class CommandeFournisseur extends CommonOrder
$this->statutshort[9] = 'StatusSupplierOrderRefusedShort';
}
- $billedtext='';
- //if ($statut==5 && $this->billed == 1) $statut = 8;
- if ($billed == 1) $billedtext=$langs->trans("Billed");
+ $statustrans = array(
+ 0 => 'status0',
+ 1 => 'status1',
+ 2 => 'status3',
+ 3 => 'status3',
+ 4 => 'status3',
+ 5 => 'status6',
+ 6 => 'status5',
+ 7 => 'status5',
- if ($mode == 0)
- {
- return $langs->trans($this->statuts[$statut]);
+ 9 => 'status5',
+ );
+
+ $statusClass = 'status0';
+ if(!empty($statustrans[$status])){
+ $statusClass = $statustrans[$status];
}
- elseif ($mode == 1)
- {
- return $langs->trans($this->statutshort[$statut]);
- }
- elseif ($mode == 2)
- {
- return $langs->trans($this->statuts[$statut]);
- }
- elseif ($mode == 3)
- {
- if ($statut==0) return img_picto($langs->trans($this->statuts[$statut]), 'statut0');
- elseif ($statut==1) return img_picto($langs->trans($this->statuts[$statut]), 'statut1');
- elseif ($statut==2) return img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==3) return img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==4) return img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==5) return img_picto($langs->trans($this->statuts[$statut]), 'statut6');
- elseif ($statut==6 || $statut==7) return img_picto($langs->trans($this->statuts[$statut]), 'statut5');
- elseif ($statut==9) return img_picto($langs->trans($this->statuts[$statut]), 'statut5');
- }
- elseif ($mode == 4)
- {
- if ($statut==0) return img_picto($langs->trans($this->statuts[$statut]), 'statut0').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==1) return img_picto($langs->trans($this->statuts[$statut]), 'statut1').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==2) return img_picto($langs->trans($this->statuts[$statut]), 'statut3').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==3) return img_picto($langs->trans($this->statuts[$statut]), 'statut3').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==4) return img_picto($langs->trans($this->statuts[$statut]), 'statut3').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==5) return img_picto($langs->trans($this->statuts[$statut]), 'statut6').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==6 || $statut==7) return img_picto($langs->trans($this->statuts[$statut]), 'statut5').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- elseif ($statut==9) return img_picto($langs->trans($this->statuts[$statut]), 'statut5').' '.$langs->trans($this->statuts[$statut]).($billedtext?' - '.$billedtext:'');
- }
- elseif ($mode == 5)
- {
- if ($statut==0) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut0');
- elseif ($statut==1) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut1');
- elseif ($statut==2) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==3) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==4) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut3');
- elseif ($statut==5) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut6');
- elseif ($statut==6 || $statut==7) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut5');
- elseif ($statut==9) return ''.$langs->trans($this->statutshort[$statut]).' '.img_picto($langs->trans($this->statuts[$statut]), 'statut5');
+
+ $billedtext = '';
+ if($mode == 4 && $billed){
+ $billedtext = ' - '.$langs->trans("Billed");
}
+
+ $statusLong = $langs->trans($this->statuts_long[$status]).$billedtext;
+ $statusShort = $langs->trans($this->statutshort[$status]);
+
+ return dolGetStatus($statusLong, $statusShort, '', $statusClass, $mode);
}
@@ -625,18 +625,17 @@ class CommandeFournisseur extends CommonOrder
* Return label of a status
*
- * @param int $statut Id statut
+ * @param int $status Id statut
* @param int $mode 0=Long label, 1=Short label, 2=Picto + Short label, 3=Picto, 4=Picto + Long label, 5=Short label + Picto
* @param int $billed 1=Billed
diff --git a/htdocs/projet/class/project.class.php b/htdocs/projet/class/project.class.php
index 027fe6503b2..e14cd53c3c3 100644
--- a/htdocs/projet/class/project.class.php
+++ b/htdocs/projet/class/project.class.php
@@ -942,48 +942,27 @@ class Project extends CommonObject
/**
* Renvoi status label for a status
*
* @param int $statut id statut
* @param int $mode 0=long label, 1=short label, 2=Picto + short label, 3=Picto, 4=Picto + long label, 5=Short label + Picto
* @return string Label
*/
- public function LibStatut($statut, $mode = 0)
+ public function LibStatut($status, $mode = 0)
{
// phpcs:enable
global $langs;
- if ($mode == 0) {
- return $langs->trans($this->statuts_long[$statut]);
- } elseif ($mode == 1) {
- return $langs->trans($this->statuts_short[$statut]);
- } elseif ($mode == 2) {
- if ($statut == 0)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut0') . ' ' . $langs->trans($this->statuts_short[$statut]);
- elseif ($statut == 1)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut4') . ' ' . $langs->trans($this->statuts_short[$statut]);
- elseif ($statut == 2)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut6') . ' ' . $langs->trans($this->statuts_short[$statut]);
- } elseif ($mode == 3) {
- if ($statut == 0)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut0');
- elseif ($statut == 1)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut4');
- elseif ($statut == 2)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut6');
- } elseif ($mode == 4) {
- if ($statut == 0)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut0') . ' ' . $langs->trans($this->statuts_long[$statut]);
- elseif ($statut == 1)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut4') . ' ' . $langs->trans($this->statuts_long[$statut]);
- if ($statut == 2)
- return img_picto($langs->trans($this->statuts_long[$statut]), 'statut6') . ' ' . $langs->trans($this->statuts_long[$statut]);
- } elseif ($mode == 5) {
- if ($statut == 0)
- return $langs->trans($this->statuts_short[$statut]) . ' ' . img_picto($langs->trans($this->statuts_long[$statut]), 'statut0');
- elseif ($statut == 1)
- return $langs->trans($this->statuts_short[$statut]) . ' ' . img_picto($langs->trans($this->statuts_long[$statut]), 'statut4');
- elseif ($statut == 2)
- return $langs->trans($this->statuts_short[$statut]) . ' ' . img_picto($langs->trans($this->statuts_long[$statut]), 'statut6');
+ $statustrans = array(
+ 0 => 'status0',
+ 1 => 'status4',
+ 2 => 'status6',
+ );
+
+ $statusClass = 'status0';
+ if(!empty($statustrans[$status])){
+ $statusClass = $statustrans[$status];
}
+
+ return dolGetStatus($langs->trans($this->statuts_long[$status]), $langs->trans($this->statuts_short[$status]), '', $statusClass, $mode);
}
/**
@@ -942,48 +942,27 @@ class Project extends CommonObject
* Renvoi status label for a status
*
- * @param int $statut id statut
- * @param int $mode 0=long label, 1=short label, 2=Picto + short label, 3=Picto, 4=Picto + long label, 5=Short label + Picto
+ * @param int $status id status
+ * @param int $mode 0=long label, 1=short label, 2=Picto + short label, 3=Picto, 4=Picto + long label, 5=Short label + Picto, 6=Long label + Picto
* @return string Label
*/